@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2013 Aurimas Cernius
+ * Copyright (C) 2010-2014 Aurimas Cernius
  * Copyright (C) 2009, 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -37,6 +37,8 @@
 #include "addinpreferencefactory.hpp"
 #include "debug.hpp"
 #include "ignote.hpp"
+#include "preferences.hpp"
+#include "preferencetabaddin.hpp"
 #include "watchers.hpp"
 #include "notebooks/notebookapplicationaddin.hpp"
 #include "notebooks/notebooknoteaddin.hpp"
@@ -57,21 +59,38 @@ namespace gnote {
                                      klass::create()))
 
 #define SETUP_NOTE_ADDIN(key, KEY, klass) \
-{ \
-  if(key == KEY) { \
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj() \
-      .get_schema_settings(Preferences::SCHEMA_GNOTE); \
-    if(settings->get_boolean(key)) { \
-      sharp::IfaceFactoryBase *iface = new sharp::IfaceFactory<klass>; \
-      m_builtin_ifaces.push_back(iface); \
-      load_note_addin(typeid(klass).name(), iface); \
+  do { \
+    if(key == KEY) { \
+      Glib::RefPtr<Gio::Settings> settings = Preferences::obj() \
+        .get_schema_settings(Preferences::SCHEMA_GNOTE); \
+      if(settings->get_boolean(key)) { \
+        sharp::IfaceFactoryBase *iface = new sharp::IfaceFactory<klass>; \
+        m_builtin_ifaces.push_back(iface); \
+        load_note_addin(typeid(klass).name(), iface); \
+      } \
+      else { \
+        erase_note_addin_info(typeid(klass).name()); \
+      } \
     } \
-    else { \
-      erase_note_addin_info(typeid(klass).name()); \
-    } \
-  } \
+  } while(0)
+
+namespace {
+  template <typename AddinType>
+  std::string get_id_for_addin(const AbstractAddin & addin, const std::map<std::string, AddinType*> & addins)
+  {
+    const AddinType *plugin = dynamic_cast<const AddinType*>(&addin);
+    if(plugin != NULL) {
+      for(typename std::map<std::string, AddinType*>::const_iterator iter = addins.begin(); iter != addins.end(); ++iter) {
+        if(iter->second == plugin) {
+          return iter->first;
+        }
+      }
+    }
+    return "";
+  }
 }
 
+
   AddinManager::AddinManager(NoteManager & note_manager, const std::string & conf_dir)
     : m_note_manager(note_manager)
     , m_gnote_conf_dir(conf_dir)
@@ -193,6 +212,9 @@ namespace gnote {
     for(std::list<std::string>::iterator iter = files.begin(); iter != files.end(); ++iter) {
       try {
         AddinInfo addin_info(*iter);
+        if(!addin_info.validate(LIBGNOTE_RELEASE, LIBGNOTE_VERSION_INFO)) {
+          continue;
+        }
         std::string module = Glib::build_filename(path, addin_info.addin_module());
         if(sharp::file_exists(module + "." + G_MODULE_SUFFIX)) {
           addin_info.addin_module(module);
@@ -484,6 +506,29 @@ namespace gnote {
     return AddinInfo();
   }
 
+  AddinInfo AddinManager::get_addin_info(const AbstractAddin & addin) const
+  {
+    std::string id;
+    id = get_id_for_addin(addin, m_app_addins);
+    if(id.empty()) {
+      id = get_id_for_addin(addin, m_pref_tab_addins);
+    }
+    if(id.empty()) {
+      id = get_id_for_addin(addin, m_sync_service_addins);
+    }
+    if(id.empty()) {
+      id = get_id_for_addin(addin, m_import_addins);
+    }
+    for(NoteAddinMap::const_iterator iter = m_note_addins.begin();
+        id.empty() && iter != m_note_addins.end(); ++iter) {
+      id = get_id_for_addin(addin, iter->second);
+    }
+    if(id.empty()) {
+      return AddinInfo();
+    }
+    return get_addin_info(id);
+  }
+
   bool AddinManager::is_module_loaded(const std::string & id) const
   {
     AddinInfo info = get_addin_info(id);
