@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013 Aurimas Cernius
+ * Copyright (C) 2012-2014 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -86,8 +86,8 @@ namespace gnote {
       if ((iter->first->get_parent() == NULL) ||
           (iter->first->get_parent() != window->embeddable_toolbar())) {
         Gtk::Grid *grid = window->embeddable_toolbar();
-        int col = grid->get_children().size();
-        grid->attach(*(iter->first), col, 0, 1, 1);
+        grid->insert_column(iter->second);
+        grid->attach(*iter->first, iter->second, 0, 1, 1);
       }
     }
   }
@@ -111,7 +111,8 @@ namespace gnote {
       
     if (m_note->is_opened()) {
       Gtk::Grid *grid = get_window()->embeddable_toolbar();
-      grid->attach(*item, grid->get_children().size(), 0, 1, 1);
+      grid->insert_column(position);
+      grid->attach(*item, position, 0, 1, 1);
     }
   }
 
