@@ -239,6 +239,11 @@ namespace gnote {
   {
     Glib::RefPtr<Gtk::TextMark> insert_mark = get_insert();
     Gtk::TextIter iter = get_iter_at_mark(insert_mark);
+    return is_bulleted_list_active(iter);
+  }
+
+  bool NoteBuffer::is_bulleted_list_active(Gtk::TextIter iter)
+  {
     iter.set_line_offset(0);
 
     Glib::RefPtr<Gtk::TextTag> depth = find_depth_tag(iter);
@@ -376,11 +381,13 @@ namespace gnote {
       // previous line.
     } 
     else if (prev_depth) {
-      iter.forward_char();
+      if(!iter.ends_line()) {
+        iter.forward_to_line_end();
+      }
 
       // See if the line was left contentless and remove the bullet
       // if so.
-      if (iter.ends_line() || insert_iter.get_line_offset() < 3 ) {
+      if(iter.get_line_offset() < 3) {
         Gtk::TextIter start = get_iter_at_line(iter.get_line());
         Gtk::TextIter end_iter = start;
         end_iter.forward_to_line_end();
@@ -555,7 +562,7 @@ namespace gnote {
     else if (start.ends_line() && start.get_line() < get_line_count()) {
       Gtk::TextIter next = get_iter_at_line (start.get_line() + 1);
       end_iter = start;
-      if(is_bulleted_list_active()) {
+      if(is_bulleted_list_active() || is_bulleted_list_active(next)) {
         end_iter.forward_chars(3);
       }
       else {
