@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2013 Aurimas Cernius
+ * Copyright (C) 2010-2014 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -95,7 +95,9 @@ namespace gnote {
   {
     if(!m_inhibit_activate) {
       if(m_note) {
-        MainWindow::present_in_new_window(m_note, true);
+        MainWindow::present_in_new_window(m_note,
+          Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
+            Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE));
       }
     }
   }
@@ -287,11 +289,8 @@ namespace gnote {
 
     // List the most recently changed notes, any currently
     // opened notes, and any pinned notes...
-    const Note::List & notes(m_manager.get_notes());
-    for(Note::List::const_iterator iter = notes.begin();
-        iter != notes.end(); ++iter) {
-
-      const Note::Ptr & note(*iter);
+    FOREACH(const NoteBase::Ptr & iter, m_manager.get_notes()) {
+      Note::Ptr note(static_pointer_cast<Note>(iter));
       
       if (note->is_special()) {
         DBG_OUT("skipping special note '%s'", note->get_title().c_str());
@@ -326,9 +325,9 @@ namespace gnote {
       }
     }
 
-    Note::Ptr start = m_manager.find_by_uri(m_manager.start_note_uri());
+    NoteBase::Ptr start = m_manager.find_by_uri(m_manager.start_note_uri());
     if (start) {
-      item = Gtk::manage(new NoteMenuItem(start, false));
+      item = Gtk::manage(new NoteMenuItem(static_pointer_cast<Note>(start), false));
       m_tray_menu->insert(*item, -1);
       list_size++;
 
@@ -363,7 +362,8 @@ namespace gnote {
     MainWindow &win = IGnote::obj().new_main_window();
     win.new_note();
     win.present();
-    win.close_on_escape(true);
+    win.close_on_escape(Preferences::obj().get_schema_settings(
+      Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE));
   }
 
   void Tray::on_search_notes_activate()
